@@ -2,19 +2,28 @@ package Test::Database::Driver::DBM;
 use strict;
 use warnings;
 
+use File::Spec;
+use File::Path;
+use DBD::DBM;
+
 use Test::Database::Driver;
 our @ISA = qw( Test::Database::Driver );
 
-use File::Spec;
-use File::Path;
+sub is_filebased {1}
 
-__PACKAGE__->init();
+sub _version { return DBD::DBM->VERSION; }
 
-sub create_database {
-    my ( $class, $config, $dbname ) = @_;
-    my $dbdir = File::Spec->catdir( $class->base_dir(), $dbname );
+sub dsn {
+    my ( $self, $dbname ) = @_;
+    my $dbdir = File::Spec->catdir( $self->base_dir(), $dbname );
+    mkpath( [$dbdir] );
+    return "dbi:DBM:f_dir=$dbdir";
+}
 
-    return Test::Database::Handle->new( dsn => "dbi:DBM:f_dir=$dbdir" );
+sub drop_database {
+    my ( $self, $dbname ) = @_;
+    my $dbdir = File::Spec->catdir( $self->base_dir(), $dbname );
+    rmtree( [$dbdir] );
 }
 
 'DBM';
@@ -23,7 +32,7 @@ __END__
 
 =head1 NAME
 
-Test::Database::Driver::DBM - A Test::Database driver for CSV
+Test::Database::Driver::DBM - A Test::Database driver for DBM
 
 =head1 SYNOPSIS
 
@@ -44,7 +53,7 @@ Philippe Bruhat (BooK), C<< <book@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright 2008 Philippe Bruhat (BooK), all rights reserved.
+Copyright 2008-2009 Philippe Bruhat (BooK), all rights reserved.
 
 =head1 LICENSE
 
