@@ -5,15 +5,23 @@ use warnings;
 use Test::Database::Driver;
 our @ISA = qw( Test::Database::Driver );
 
+use DBI;
 use File::Spec;
 
-__PACKAGE__->init();
+sub is_filebased {1}
 
-sub create_database {
-    my ( $class, $config, $dbname ) = @_;
-    my $dbfile = File::Spec->catfile( $class->base_dir(), $dbname );
+sub _version { return DBI->connect( $_[0]->bare_dsn() )->{sqlite_version}; }
 
-    return Test::Database::Handle->new( dsn => "dbi:SQLite:dbname=$dbfile", );
+sub dsn {
+    my ( $self, $dbname ) = @_;
+    return 'dbi:SQLite:dbname='
+        . File::Spec->catdir( $self->base_dir(), $dbname );
+}
+
+sub drop_database {
+    my ( $self, $dbname ) = @_;
+    my $dbfile = File::Spec->catfile( $self->base_dir(), $dbname );
+    unlink $dbfile;
 }
 
 'SQLite';
@@ -43,7 +51,7 @@ Philippe Bruhat (BooK), C<< <book@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright 2008 Philippe Bruhat (BooK), all rights reserved.
+Copyright 2008-2009 Philippe Bruhat (BooK), all rights reserved.
 
 =head1 LICENSE
 
